@@ -18,35 +18,46 @@
 
 from pyes import ES
 from scrapy import log
-from scrapy.utils.project import get_project_settings
 import hashlib
 import types
 
 class ElasticSearchPipeline(object):
-    def __init__(self):
-        self.settings = get_project_settings()
+    settings = None
+    es = None
 
-        basic_auth = {'username': self.settings['ELASTICSEARCH_USERNAME'], 'password': self.settings['ELASTICSEARCH_PASSWORD']}
+    @classmethod
+    def from_crawler(cls, crawler):
+        ext = cls()
+        ext.settings = crawler.settings
 
-        if self.settings['ELASTICSEARCH_PORT']:
-            uri = "%s:%d" % (self.settings['ELASTICSEARCH_SERVER'], self.settings['ELASTICSEARCH_PORT'])
+        basic_auth = {}
+
+        if (ext.settings['ELASTICSEARCH_USERNAME']):
+            basic_auth['username'] = ext.settings['ELASTICSEARCH_USERNAME']
+
+        if (ext.settings['ELASTICSEARCH_PASSWORD']):
+            basic_auth['password'] = ext.settings['ELASTICSEARCH_PASSWORD']
+
+        if ext.settings['ELASTICSEARCH_PORT']:
+            uri = "%s:%d" % (ext.settings['ELASTICSEARCH_SERVER'], ext.settings['ELASTICSEARCH_PORT'])
         else:
-            uri = "%s" % (self.settings['ELASTICSEARCH_SERVER'])
+            uri = "%s" % (ext.settings['ELASTICSEARCH_SERVER'])
 
-        self.es = ES([uri], basic_auth=basic_auth)
+        ext.es = ES([uri], basic_auth=basic_auth)
+        return ext
 
     def index_item(self, item):
-        if self.settings['ELASTICSEARCH_UNIQ_KEY']:
-            uniq_key = self.settings['ELASTICSEARCH_UNIQ_KEY']
+        if self.settings.get('ELASTICSEARCH_UNIQ_KEY'):
+            uniq_key = self.settings.get('ELASTICSEARCH_UNIQ_KEY')
             local_id = hashlib.sha1(item[uniq_key]).hexdigest()
-            log.msg("Generated unique key %s" % local_id, level=self.settings['ELASTICSEARCH_LOG_LEVEL'])
+            log.msg("Generated unique key %s" % local_id, level=self.settings.get('ELASTICSEARCH_LOG_LEVEL'))
             op_type = 'index'
         else:
             op_type = 'create'
             local_id = item['id']
         self.es.index(dict(item),
-                      self.settings['ELASTICSEARCH_INDEX'],
-                      self.settings['ELASTICSEARCH_TYPE'],
+                      self.settings.get('ELASTICSEARCH_INDEX'),
+                      self.settings.get('ELASTICSEARCH_TYPE'),
                       id=local_id,
                       op_type=op_type)
 
@@ -58,6 +69,6 @@ class ElasticSearchPipeline(object):
         else:
             self.index_item(item)
             log.msg("Item sent to Elastic Search %s" %
-                    (self.settings['ELASTICSEARCH_INDEX']),
-                    level=self.settings['ELASTICSEARCH_LOG_LEVEL'], spider=spider)
-            return item
+                    (self.settings.get('ELASTICSEARCH_INDEX')),
+                    level=self.settings.get('ELASTICSEARCH_LOG_LEVEL'), spider=spider)
+            return item
\ No newline at end of file
